TITLE Calcium inactivated L-type Calcium channels
:
: Based on models by V. Booth et al. J Neurophysiol 78:3371-3385, 1997 
: and Markaki et al. Neurocomput 65-66:305-314, 2005
:


NEURON {
	SUFFIX L_Ca
	USEION ca READ eca, cai WRITE ica
	RANGE gcabar
	RANGE m_inf, h
	GLOBAL ki, tau_m
}


UNITS {
	(mA) = (milliamp)
	(mV) = (millivolt)
	(molar) = (1/liter)
	(mM) = (millimolar)
}

PARAMETER {
	gcabar  = 0.0003  (mho/cm2)
	eca		(mV)	: eca can't be set here, only in hoc
	dt		(ms)
	v		(mV)
	cai = 2.4e-4 (mM) :initial [Ca]i
	tau_m	= 20	(ms)
	ki = 1.245 (mM)
}

STATE {
	m
}

ASSIGNED {
	ica		(mA/cm2)
	m_inf
	h
}

BREAKPOINT {
	SOLVE states METHOD cnexp
	ica = gcabar * m * m * h * (v - eca) 
}

DERIVATIVE states {
	evaluate_fct(v,cai)
	m' = (m_inf - m) / tau_m
}

UNITSOFF
INITIAL {
	evaluate_fct(v,cai)
	m = m_inf
}

PROCEDURE evaluate_fct(v(mV),cai(mM)) {
	m_inf = 1 / (1 + (Exp((v + 30)/-6)))
	h = ki/(cai + ki)
}

FUNCTION Exp(x) {
	if (x < -100) {
		Exp = 0
	}else{
		Exp = exp(x)
	}
} 
