TITLE adp.mod

COMMENT
This is an ADP generating, TTX insensitive Na current, modeled 
loosely off of McQuiston and Madison, J. Neurosci, 1999. This will
only work in single compartment models, as it is a point process.
ENDCOMMENT

NEURON {
	POINT_PROCESS adp
	NONSPECIFIC_CURRENT i
	RANGE mtau, htau, e, gbar, g, i, r0
}

UNITS {
	(nA) = (nanoamp)
	(mV) = (millivolt)
	(uS) = (microsiemens)
}

PARAMETER {
	e = 50 (mV)
	mtau = 100(ms) <1e-9,1e9>
	htau = 500(ms) <1e-9,1e9>
	gbar = 0 (uS)
	r0 = 5 (ms)
}

ASSIGNED {
	v (mV)
	i (nA)
	g (uS)
	factor
	refract
	tf
}

STATE {
	A (uS)
	B (uS)
}

INITIAL {
	LOCAL tp
	A = 0
	B = 0
	i = 0
	refract = 0
	tp = (mtau*htau)/(htau - mtau) * log(htau/mtau)
	factor = -exp(-tp/mtau) + exp(-tp/htau)
	factor = 1/factor
}

BREAKPOINT {
	SOLVE state METHOD cnexp
	if (refract == 0 && v > 30){
			A = 0
			B = 0
			state_discontinuity(A, A + gbar*factor)
			state_discontinuity(B, B + gbar*factor)
			refract = 1
			tf = t + r0
		} else if (refract == 1 && t > tf){
			refract = 0
	}		
	g = B - A
	i = g*(v - e)
} 

DERIVATIVE state {
	A' = -A/mtau
	B' = -B/htau
}